@@ -29,8 +29,6 @@
 #include "lpconfig.h"
 
 extern LinphoneProxyConfig *linphone_core_get_proxy_config_from_rid(LinphoneCore *lc, int rid);
-extern void linphone_proxy_config_set_realm(LinphoneProxyConfig *cfg, const char *realm);
-extern void linphone_core_retry_proxy_register(LinphoneCore *lc, const char *realm);
 
 LinphoneAuthInfo *linphone_auth_info_new(const char *username, const char *userid,
 				   										const char *passwd, const char *ha1,const char *realm)
@@ -95,7 +93,6 @@ void linphone_auth_info_write_config(LpConfig *config, LinphoneAuthInfo *obj, in
 	if (obj->realm!=NULL){
 		lp_config_set_string(config,key,"realm",obj->realm);
 	}
-	lp_config_sync(config);
 }
 
 LinphoneAuthInfo *linphone_auth_info_new_from_config_file(LpConfig * config, int pos)
@@ -123,22 +120,48 @@ static bool_t key_match(const char *tmp1, const char *tmp2){
 	
 }
 
+static char * remove_quotes(char * input){
+	char *tmp;
+	if (*input=='"') input++;
+	tmp=strchr(input,'"');
+	if (tmp) *tmp='\0';
+	return input;
+}
+
+static int realm_match(const char *realm1, const char *realm2){
+	if (realm1==NULL && realm2==NULL) return TRUE;
+	if (realm1!=NULL && realm2!=NULL){
+		if (strcmp(realm1,realm2)==0) return TRUE;
+		else{
+			char tmp1[128];
+			char tmp2[128];
+			char *p1,*p2;
+			strncpy(tmp1,realm1,sizeof(tmp1)-1);
+			strncpy(tmp2,realm2,sizeof(tmp2)-1);
+			p1=remove_quotes(tmp1);
+			p2=remove_quotes(tmp2);
+			return strcmp(p1,p2)==0;
+		}
+	}
+	return FALSE;
+}
+
 static int auth_info_compare(const void *pinfo,const void *pref){
 	LinphoneAuthInfo *info=(LinphoneAuthInfo*)pinfo;
 	LinphoneAuthInfo *ref=(LinphoneAuthInfo*)pref;
-	if (key_match(info->realm,ref->realm) && key_match(info->username,ref->username)) return 0;
+	if (realm_match(info->realm,ref->realm) && key_match(info->username,ref->username)) return 0;
 	return -1;
 }
 
 static int auth_info_compare_only_realm(const void *pinfo,const void *pref){
 	LinphoneAuthInfo *info=(LinphoneAuthInfo*)pinfo;
 	LinphoneAuthInfo *ref=(LinphoneAuthInfo*)pref;
-	if (key_match(info->realm,ref->realm) ) return 0;
+	if (realm_match(info->realm,ref->realm) ) return 0;
 	return -1;
 }
 
 
-LinphoneAuthInfo *linphone_core_auth_info_find(LinphoneCore *lc, const char *realm, const char *username)
+LinphoneAuthInfo *linphone_core_find_auth_info(LinphoneCore *lc, const char *realm, const char *username)
 {
 	LinphoneAuthInfo ref;
 	MSList *elem;
@@ -199,6 +222,10 @@ void linphone_core_remove_auth_info(LinphoneCore *lc, LinphoneAuthInfo *info){
 	
 }
 
+const MSList *linphone_core_get_auth_info_list(const LinphoneCore *lc){
+	return lc->auth_info;
+}
+
 void linphone_core_clear_all_auth_info(LinphoneCore *lc){
 	MSList *elem;
 	int i;
@@ -236,9 +263,9 @@ void linphone_authentication_ok(LinphoneCore *lc, eXosip_event_t *ev){
 	}
 	/* see if we already have this auth information , not to ask it everytime to the user */
 	if (prx_realm!=NULL)
-		as=linphone_core_auth_info_find(lc,prx_realm,username);
+		as=linphone_core_find_auth_info(lc,prx_realm,username);
 	if (www_realm!=NULL) 
-		as=linphone_core_auth_info_find(lc,www_realm,username);
+		as=linphone_core_find_auth_info(lc,www_realm,username);
 	if (as){
 		ms_message("Authentication for user=%s realm=%s is working.",username,prx_realm ? prx_realm : www_realm);
 		as->works=TRUE;
@@ -248,7 +275,7 @@ void linphone_authentication_ok(LinphoneCore *lc, eXosip_event_t *ev){
 
 void linphone_core_find_or_ask_for_auth_info(LinphoneCore *lc,const char *username,const char* realm, int tid)
 {
-	LinphoneAuthInfo *as=linphone_core_auth_info_find(lc,realm,username);
+	LinphoneAuthInfo *as=linphone_core_find_auth_info(lc,realm,username);
 	if ( as==NULL || (as!=NULL && as->works==FALSE && as->first_time==FALSE)){
 		if (lc->vtable.auth_info_requested!=NULL){
 			lc->vtable.auth_info_requested(lc,realm,username);
