@@ -22,6 +22,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "lpconfig.h"
 #include "private.h"
 #include "mediastreamer2/mediastream.h"
+#include "mediastreamer2/msvolume.h"
 #include <eXosip2/eXosip.h>
 #include "sdphandler.h"
 
@@ -191,7 +192,9 @@ void linphone_call_log_completed(LinphoneCallLog *calllog, LinphoneCall *call){
 				char *info;
 				calllog->status=LinphoneCallMissed;
 				lc->missed_calls++;
-				info=ortp_strdup_printf(_("You have missed %i call(s)."),lc->missed_calls);
+				info=ortp_strdup_printf(ngettext("You have missed %i call.",
+                            "You have missed %i calls.", lc->missed_calls),
+                        lc->missed_calls);
 				lc->vtable.display_status(lc,info);
 				ms_free(info);
 			}
@@ -405,6 +408,9 @@ void sound_config_read(LinphoneCore *lc)
 
 	linphone_core_enable_echo_cancelation(lc,
 		lp_config_get_int(lc->config,"sound","echocancelation",0));
+
+	linphone_core_enable_echo_limiter(lc,
+		lp_config_get_int(lc->config,"sound","echolimiter",0));
 }
 
 void sip_config_read(LinphoneCore *lc)
@@ -1021,6 +1027,9 @@ void linphone_core_iterate(LinphoneCore *lc)
 			eXosip_unlock();
 		}
 	}
+
+	ms_list_for_each(lc->sip_conf.proxies,(void (*)(void*))&linphone_proxy_config_update);
+
 	if (lc->call!=NULL){
 		LinphoneCall *call=lc->call;
 		
@@ -1407,6 +1416,13 @@ int linphone_core_change_qos(LinphoneCore *lc, int answer)
 
 void linphone_core_init_media_streams(LinphoneCore *lc){
 	lc->audiostream=audio_stream_new(linphone_core_get_audio_port(lc),linphone_core_ipv6_enabled(lc));
+	if (linphone_core_echo_limiter_enabled(lc)){
+		const char * type=lp_config_get_string(lc->config,"sound","el_type","mic");
+		if (strcasecmp(type,"mic")==0)
+			audio_stream_enable_echo_limiter(lc->audiostream,ELControlMic);
+		else if (strcasecmp(type,"speaker")==0)
+			audio_stream_enable_echo_limiter(lc->audiostream,ELControlSpeaker);
+	}
 #ifdef VIDEO_ENABLED
 	if (lc->video_conf.display || lc->video_conf.capture)
 		lc->videostream=video_stream_new(linphone_core_get_video_port(lc),linphone_core_ipv6_enabled(lc));
@@ -1421,6 +1437,40 @@ static void linphone_core_dtmf_received(RtpSession* s, int dtmf, void* user_data
 		lc->vtable.dtmf_received(lc, dtmf);
 }
 
+static void post_configure_audio_streams(LinphoneCore *lc){
+	AudioStream *st=lc->audiostream;
+	if (st->volrecv && st->volsend){
+		float speed=lp_config_get_float(lc->config,"sound","el_speed",-1);
+		float thres=lp_config_get_float(lc->config,"sound","el_thres",-1);
+		float force=lp_config_get_float(lc->config,"sound","el_force",-1);
+		MSFilter *f=NULL;
+		if (st->el_type==ELControlMic){
+			f=st->volsend;
+			if (speed==-1) speed=0.03;
+			if (force==-1) force=10;
+		}
+		else if (st->el_type==ELControlSpeaker){
+			f=st->volrecv;
+			if (speed==-1) speed=0.02;
+			if (force==-1) force=5;
+		}else {
+			ms_fatal("Should not happen");
+			return;
+		}
+		if (speed!=-1)
+			ms_filter_call_method(f,MS_VOLUME_SET_EA_SPEED,&speed);
+		if (thres!=-1)
+			ms_filter_call_method(f,MS_VOLUME_SET_EA_THRESHOLD,&thres);
+		if (force!=-1)
+			ms_filter_call_method(f,MS_VOLUME_SET_EA_FORCE,&force);
+	}
+	if (lc->vtable.dtmf_received!=NULL){
+		/* replace by our default action*/
+		audio_stream_play_received_dtmfs(lc->audiostream,FALSE);
+		rtp_session_signal_connect(lc->audiostream->session,"telephone-event",(RtpCallback)linphone_core_dtmf_received,(unsigned long)lc);
+	}
+}
+
 void linphone_core_start_media_streams(LinphoneCore *lc, LinphoneCall *call){
 	osip_from_t *me=linphone_core_get_primary_contact_parsed(lc);
 	const char *tool="linphone-" LINPHONE_VERSION;
@@ -1465,11 +1515,7 @@ void linphone_core_start_media_streams(LinphoneCore *lc, LinphoneCall *call){
 				lc->play_file,
 				lc->rec_file);
 		}
-		if (lc->vtable.dtmf_received!=NULL){
-			/* replace by our default action*/
-			audio_stream_play_received_dtmfs(lc->audiostream,FALSE);
-			rtp_session_signal_connect(lc->audiostream->session,"telephone-event",(RtpCallback)linphone_core_dtmf_received,(unsigned long)lc);
-		}
+		post_configure_audio_streams(lc);	
 		audio_stream_set_rtcp_information(lc->audiostream, cname, tool);
 	}
 #ifdef VIDEO_ENABLED
@@ -1882,6 +1928,14 @@ bool_t linphone_core_echo_cancelation_enabled(LinphoneCore *lc){
 	return lc->sound_conf.ec;
 }
 
+void linphone_core_enable_echo_limiter(LinphoneCore *lc, bool_t val){
+	lc->sound_conf.ea=val;
+}
+
+bool_t linphone_core_echo_limiter_enabled(const LinphoneCore *lc){
+	return lc->sound_conf.ea;
+}
+
 
 void linphone_core_send_dtmf(LinphoneCore *lc,char dtmf)
 {
@@ -2108,7 +2162,7 @@ int linphone_core_set_video_device(LinphoneCore *lc, const char *id){
 	if (olddev!=NULL && olddev!=lc->video_conf.device){
 		toggle_video_preview(lc,FALSE);/*restart the video local preview*/
 	}
-	if (lc->ready){
+	if (lc->ready && lc->video_conf.device){
 		vd=ms_web_cam_get_string_id(lc->video_conf.device);
 		if (vd && strstr(vd,"Static picture")!=NULL){
 			vd=NULL;
@@ -2247,6 +2301,31 @@ void linphone_core_set_mtu(LinphoneCore *lc, int mtu){
 	}else ms_set_mtu(0);//use mediastreamer2 default value
 }
 
+void linphone_core_start_waiting(LinphoneCore *lc, const char *purpose){
+	if (lc->vtable.waiting){
+		lc->wait_ctx=lc->vtable.waiting(lc,NULL,LinphoneWaitingStart,purpose,0);
+	}
+}
+
+void linphone_core_update_progress(LinphoneCore *lc, const char *purpose, float progress){
+	if (lc->vtable.waiting){
+		lc->wait_ctx=lc->vtable.waiting(lc,lc->wait_ctx,LinphoneWaitingProgress,purpose,progress);
+	}else{
+#ifdef WIN32
+		Sleep(50000);
+#else
+		usleep(50000);
+#endif
+	}
+}
+
+void linphone_core_stop_waiting(LinphoneCore *lc){
+	if (lc->vtable.waiting){
+		lc->wait_ctx=lc->vtable.waiting(lc,lc->wait_ctx,LinphoneWaitingFinished,NULL,0);
+	}
+}
+
+
 void net_config_uninit(LinphoneCore *lc)
 {
 	net_config_t *config=&lc->net_conf;
@@ -2376,6 +2455,18 @@ LpConfig *linphone_core_get_config(LinphoneCore *lc){
 
 void linphone_core_uninit(LinphoneCore *lc)
 {
+	if (lc->call){
+		int i;
+		linphone_core_terminate_call(lc,NULL);
+		for(i=0;i<10;++i){
+#ifndef WIN32
+			usleep(50000);
+#else
+			Sleep(50);
+#endif
+			linphone_core_iterate(lc);
+		}
+	}
 	gstate_new_state(lc, GSTATE_POWER_SHUTDOWN, NULL);
 #ifdef VIDEO_ENABLED
 	if (lc->previewstream!=NULL){
