@@ -33,7 +33,7 @@
 #endif
 
 #ifndef LINPHONE_VERSION
-#define LINPHONE_VERSION "3.0.0"
+#define LINPHONE_VERSION "3.1.1"
 #endif
 
 #ifndef LIBLINPHONE_VERSION 
@@ -57,6 +57,9 @@
 #ifndef _
 #define _(something)	(something)
 #endif
+#ifndef ngettext
+#define ngettext(singular, plural, number)	(((number)==1)?(singular):(plural))
+#endif
 #endif
 
 void linphone_core_init_media_streams(LinphoneCore *lc);
@@ -124,5 +127,6 @@ void linphone_core_update_allocated_audio_bandwidth_in_call(LinphoneCore *lc, co
 void linphone_core_run_stun_tests(LinphoneCore *lc, LinphoneCall *call);
 
 void linphone_core_write_friends_config(LinphoneCore* lc);
+void linphone_proxy_config_update(LinphoneProxyConfig *cfg);
 
 #endif /* _PRIVATE_H */
