@@ -25,6 +25,14 @@ Copyright (C) 2000  Simon MORLAT (simon.morlat@linphone.org)
 #include "lpconfig.h"
 #include "private.h"
 
+void linphone_proxy_config_write_all_to_config_file(LinphoneCore *lc){
+	MSList *elem;
+	int i;
+	for(elem=lc->sip_conf.proxies,i=0;elem!=NULL;elem=ms_list_next(elem),i++){
+		LinphoneProxyConfig *cfg=(LinphoneProxyConfig*)elem->data;
+		linphone_proxy_config_write_to_config_file(lc->config,cfg,i);
+	}
+}
 
 void linphone_proxy_config_init(LinphoneProxyConfig *obj){
 	memset(obj,0,sizeof(LinphoneProxyConfig));
@@ -52,16 +60,6 @@ bool_t linphone_proxy_config_is_registered(const LinphoneProxyConfig *obj){
 	return obj->registered;
 }
 
-#if 0
-static void linphone_proxy_config_register(LinphoneProxyConfig *obj){
-	osip_message_t *msg;
-	eXosip_lock();
-	eXosip_register_build_register(obj->rid,obj->expires,&msg);
-	eXosip_register_send_register(obj->rid,msg);
-	eXosip_unlock();
-}
-#endif
-
 void linphone_proxy_config_register_again_with_updated_contact(LinphoneProxyConfig *obj, osip_message_t *orig_request, osip_message_t *last_answer){
 	osip_message_t *msg;
 	const char *rport,*received;
@@ -210,7 +208,6 @@ void linphone_proxy_config_enable_publish(LinphoneProxyConfig *obj, bool_t val){
 }
 
 void linphone_proxy_config_edit(LinphoneProxyConfig *obj){
-	obj->frozen=TRUE;
 	obj->auth_failures=0;
 	if (obj->reg_sendregister){
 		/* unregister */
@@ -231,13 +228,10 @@ void linphone_proxy_config_apply(LinphoneProxyConfig *obj,LinphoneCore *lc)
 	linphone_proxy_config_done(obj);
 }
 
-int linphone_proxy_config_done(LinphoneProxyConfig *obj)
-{
+static void linphone_proxy_config_register(LinphoneProxyConfig *obj){
 	const char *id_str;
-	if (!linphone_proxy_config_check(obj->lc,obj)) return -1;
 	if (obj->reg_identity!=NULL) id_str=obj->reg_identity;
 	else id_str=linphone_core_get_primary_contact(obj->lc);
-	obj->frozen=FALSE;
 	if (obj->reg_sendregister){
 		char *ct=NULL;
 		osip_message_t *msg=NULL;
@@ -245,6 +239,13 @@ int linphone_proxy_config_done(LinphoneProxyConfig *obj)
 		eXosip_register_send_register(obj->rid,msg);
 		if (ct!=NULL) osip_free(ct);
 	}
+}
+
+int linphone_proxy_config_done(LinphoneProxyConfig *obj)
+{
+	if (!linphone_proxy_config_check(obj->lc,obj)) return -1;
+	obj->commit=TRUE;
+	linphone_proxy_config_write_all_to_config_file(obj->lc);
 	return 0;
 }
 
@@ -502,15 +503,14 @@ const MSList *linphone_core_get_proxy_config_list(const LinphoneCore *lc){
 void linphone_proxy_config_process_authentication_failure(LinphoneCore *lc, eXosip_event_t *ev){
 	LinphoneProxyConfig *cfg=linphone_core_get_proxy_config_from_rid(lc, ev->rid);
 	if (cfg){
-			cfg->auth_failures++;
-			/*restart a new register */
-			if (cfg->auth_failures==1){
-				linphone_proxy_config_done(cfg);
-			}
+		cfg->auth_failures++;
+		/*restart a new register */
+		if (cfg->auth_failures==1){
+			linphone_proxy_config_register(cfg);
+		}
 	}
 }
 
-
 void linphone_proxy_config_write_to_config_file(LpConfig *config, LinphoneProxyConfig *obj, int index)
 {
 	char key[50];
@@ -537,6 +537,8 @@ void linphone_proxy_config_write_to_config_file(LpConfig *config, LinphoneProxyC
 	lp_config_set_int(config,key,"publish",obj->publish);
 }
 
+
+
 LinphoneProxyConfig *linphone_proxy_config_new_from_config_file(LpConfig *config, int index)
 {
 	const char *tmp;
@@ -574,24 +576,58 @@ LinphoneProxyConfig *linphone_proxy_config_new_from_config_file(LpConfig *config
 	return cfg;
 }
 
+static void linphone_proxy_config_activate_sip_setup(LinphoneProxyConfig *cfg){
+	SipSetupContext *ssc;
+	SipSetup *ss=sip_setup_lookup(cfg->type);
+	LinphoneCore *lc=linphone_proxy_config_get_core(cfg);
+	unsigned int caps;
+	if (!ss) return ;
+	ssc=sip_setup_context_new(ss,cfg);
+	cfg->ssctx=ssc;
+	if (cfg->reg_identity==NULL){
+		ms_error("Invalid identity for this proxy configuration.");
+		return;
+	}
+	caps=sip_setup_context_get_capabilities(ssc);
+	if (caps & SIP_SETUP_CAP_ACCOUNT_MANAGER){
+		if (sip_setup_context_login_account(ssc,cfg->reg_identity,NULL)!=0){
+			if (lc->vtable.display_warning){
+				char *tmp=ms_strdup_printf(_("Could not login as %s"),cfg->reg_identity);
+				lc->vtable.display_warning(lc,tmp);
+				ms_free(tmp);
+			}
+			return;
+		}
+	}
+	if (caps & SIP_SETUP_CAP_PROXY_PROVIDER){
+		char proxy[256];
+		if (sip_setup_context_get_proxy(ssc,NULL,proxy,sizeof(proxy))==0){
+			linphone_proxy_config_set_server_addr(cfg,proxy);
+		}else{
+			ms_error("Could not retrieve proxy uri !");
+		}
+	}
+	
+}
+
+void linphone_proxy_config_update(LinphoneProxyConfig *cfg){
+	if (cfg->commit){
+		if (cfg->type && cfg->ssctx==NULL){
+			linphone_proxy_config_activate_sip_setup(cfg);
+		}
+		linphone_proxy_config_register(cfg);
+		cfg->commit=FALSE;
+	}
+}
 
 void linphone_proxy_config_set_sip_setup(LinphoneProxyConfig *cfg, const char *type){
-	SipSetup *ss=sip_setup_lookup(type);
-	SipSetupContext *ssc;
 	if (cfg->type)
 		ms_free(cfg->type);
 	cfg->type=ms_strdup(type);
-	if (!ss) return ;
-	ssc=sip_setup_context_new(ss,cfg);
-	if (sip_setup_context_login_account(ssc,cfg->reg_identity,NULL)==0){
-		if (sip_setup_context_get_capabilities(ssc) & SIP_SETUP_CAP_PROXY_PROVIDER){
-			char proxy[256];
-			if (sip_setup_context_get_proxy(ssc,NULL,proxy,sizeof(proxy))==0){
-				linphone_proxy_config_set_server_addr(cfg,proxy);
-			}
-		}
+	if (linphone_proxy_config_get_addr(cfg)==NULL){
+		/*put a placeholder so that the sip setup gets saved into the config */
+		linphone_proxy_config_set_server_addr(cfg,"sip:undefined");
 	}
-	cfg->ssctx=ssc;
 }
 
 SipSetupContext *linphone_proxy_config_get_sip_setup_context(LinphoneProxyConfig *cfg){
