@@ -74,7 +74,8 @@ static LinphoneCoreVTable vtable={
 	.display_question=linphone_gtk_display_question,
 	.call_log_updated=linphone_gtk_call_log_updated,
 	.text_received=linphone_gtk_text_received,
-	.general_state=linphone_gtk_general_state
+	.general_state=linphone_gtk_general_state,
+	.waiting=linphone_gtk_wait
 };
 
 static gboolean verbose=0;
@@ -327,7 +328,11 @@ static void set_video_window_decorations(GdkWindow *w){
 static gboolean linphone_gtk_iterate(LinphoneCore *lc){
 	unsigned long id;
 	static unsigned long previd=0;
-
+	static gboolean in_iterate=FALSE;
+	
+	/*avoid reentrancy*/
+	if (in_iterate) return TRUE;
+	in_iterate=TRUE;
 	linphone_core_iterate(lc);
 	id=linphone_core_get_native_video_window_id(lc);
 	if (id!=previd){
@@ -343,6 +348,7 @@ static gboolean linphone_gtk_iterate(LinphoneCore *lc){
 			else ms_error("gdk_window_foreign_new() failed");
 		}
 	}
+	in_iterate=FALSE;
 	return TRUE;
 }
 
@@ -887,7 +893,9 @@ void linphone_gtk_log_handler(OrtpLogLevel lev, const char *fmt, va_list args){
 }
 
 int main(int argc, char *argv[]){
+#ifdef ENABLE_NLS
 	void *p;
+#endif
 	const char *config_file;
 	const char *lang;
 
@@ -900,6 +908,16 @@ int main(int argc, char *argv[]){
 		g_warning("This instance is going to exit now.");
 		return 0;
 	}
+#ifdef WIN32
+	/*workaround for windows: sometimes LANG is defined to an integer value, not understood by gtk */
+	if ((lang=getenv("LANG"))!=NULL){
+		if (atoi(lang)!=0){
+			char tmp[128];
+			snprintf(tmp,sizeof(tmp),"LANG=",lang);
+			_putenv(tmp);
+		}
+	}
+#endif
 	
 	if ((lang=linphone_gtk_get_lang(config_file))!=NULL && lang[0]!='\0'){
 #ifdef WIN32
