@@ -29,6 +29,12 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "ortp/ortp.h"
 #include "ortp/event.h"
 
+typedef enum EchoLimiterType{
+	ELInactive,
+	ELControlMic,
+	ELControlSpeaker
+} EchoLimiterType;
+
 struct _AudioStream
 {
 	MSTicker *ticker;
@@ -41,8 +47,10 @@ struct _AudioStream
 	MSFilter *rtpsend;
 	MSFilter *dtmfgen;
 	MSFilter *ec;/*echo canceler*/
-	unsigned int last_packet_count;
+	MSFilter *volsend,*volrecv; /*MSVolumes*/
+	uint64_t last_packet_count;
 	time_t last_packet_time;
+	EchoLimiterType el_type; /*use echo limiter: two MSVolume, measured input level controlling local output level*/
 	bool_t play_dtmfs;
 };
 
@@ -90,6 +98,9 @@ void audio_stream_set_relay_session_id(AudioStream *stream, const char *relay_se
 /*returns true if we are still receiving some data from remote end in the last timeout seconds*/
 bool_t audio_stream_alive(AudioStream * stream, int timeout);
 
+/*enable echo-limiter dispositve: one MSVolume in input branch controls a MSVolume in the output branch*/
+void audio_stream_enable_echo_limiter(AudioStream *stream, EchoLimiterType type);
+
 /* stop the above process*/
 void audio_stream_stop (AudioStream * stream);
 
