@@ -165,7 +165,7 @@ static int ice_sound_send_stun_request(RtpSession *session, struct IceCheckList
 
 		/* prepare ONCE tie-break value */
 		if (checklist->tiebreak_value==0) {
-			checklist->tiebreak_value = random() * (0x7fffffffffffffff/0x7fff);
+			checklist->tiebreak_value = random() * (0x7fffffffffffffffLL /0x7fff);
 		}
 
 		cand_pair=NULL;
@@ -413,6 +413,7 @@ static int ice_sound_send_stun_request(RtpSession *session, struct IceCheckList
 	return 0;
 }
 
+#if 0
 static int
 _ice_get_localip_for (struct sockaddr_storage *saddr, size_t saddr_len, char *loc, int size)
 {
@@ -460,6 +461,8 @@ _ice_get_localip_for (struct sockaddr_storage *saddr, size_t saddr_len, char *lo
 	return 0;
 }
 
+#endif
+
 static void
 _ice_createErrorResponse(StunMessage *response, int cl, int number, const char* msg)
 {
@@ -510,7 +513,7 @@ static int ice_process_stun_message(RtpSession *session, struct IceCheckList *ch
 
 	/* prepare ONCE tie-break value */
 	if (checklist->tiebreak_value==0) {
-		checklist->tiebreak_value = random() * (0x7fffffffffffffff/0x7fff);
+		checklist->tiebreak_value = random() * (0x7fffffffffffffffLL/0x7fff);
 	}
 
 	memset (src6host, 0, sizeof (src6host));
@@ -944,7 +947,7 @@ static int ice_process_stun_message(RtpSession *session, struct IceCheckList *ch
 		{
 			struct in_addr inaddr;
 			char mapped_addr[64];
-			struct CandidatePair *cand_pair;
+			struct CandidatePair *cand_pair=NULL;
 			int pos;
 			inaddr.s_addr = htonl (mappedAddr.addr);
 			snprintf(mapped_addr, sizeof(mapped_addr),
