@@ -659,7 +659,7 @@ static MSFilterMethod ca_methods[]={
 MSFilterDesc ca_read_desc={
 	.id=MS_CA_READ_ID,
 	.name="MSCARead",
-	.text="Sound capture filter for MacOS X Core Audio drivers",
+	.text=N_("Sound capture filter for MacOS X Core Audio drivers"),
 	.category=MS_FILTER_OTHER,
 	.ninputs=0,
 	.noutputs=1,
@@ -673,7 +673,7 @@ MSFilterDesc ca_read_desc={
 MSFilterDesc ca_write_desc={
 	.id=MS_CA_WRITE_ID,
 	.name="MSCAWrite",
-	.text="Sound playback filter for MacOS X Core Audio drivers",
+	.text=N_("Sound playback filter for MacOS X Core Audio drivers"),
 	.category=MS_FILTER_OTHER,
 	.ninputs=1,
 	.noutputs=0,
