@@ -180,6 +180,61 @@ PayloadType payload_type_g729={
 	CHANNELS(1)
 };
 
+PayloadType payload_type_g7221={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(16000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE( 24000),
+	MIME_TYPE ("G7221"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_g726_40={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE( 8000),
+	MIME_TYPE ("G726-40"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_g726_32={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE( 8000),
+	MIME_TYPE ("G726-32"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_g726_24={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE( 8000),
+	MIME_TYPE ("G726-24"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_g726_16={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE( 8000),
+	MIME_TYPE ("G726-16"),
+	CHANNELS(1)
+};
+
 PayloadType payload_type_mpv=
 {
 	TYPE( PAYLOAD_VIDEO),
@@ -290,6 +345,17 @@ PayloadType payload_type_speex_wb={
 	CHANNELS(1)
 };
 
+PayloadType payload_type_speex_uwb={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(32000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(28000),
+	MIME_TYPE ("speex"),
+	CHANNELS(1)
+};
+
 PayloadType payload_type_ilbc={
 	TYPE( PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
@@ -391,6 +457,17 @@ PayloadType payload_type_h264={
 	CHANNELS(0)
 };
 
+PayloadType payload_type_x_snow={
+	TYPE( PAYLOAD_VIDEO),
+	CLOCK_RATE(90000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(256000),
+	MIME_TYPE ("x-snow"),
+	CHANNELS(0)
+};
+
 PayloadType	payload_type_t140={
 	PAYLOAD_AUDIO_PACKETIZED, /*type */
 	1000,
@@ -403,4 +480,15 @@ PayloadType	payload_type_t140={
 	0
 };
 
+PayloadType	payload_type_x_udpftp={
+	PAYLOAD_AUDIO_PACKETIZED, /*type */
+	1000,
+	0,
+	NULL,
+	0,
+	0,
+	"x-udpftp",
+	0,
+	0
+};
 
